@@ -20,16 +20,11 @@ BEGIN {
         ? sub () { 0 }
         : sub () { 1 };
 
-    sub HAVE_ISAREV () {
-        Carp::cluck("Class::MOP::HAVE_ISAREV is deprecated and will be removed in a future release. It has always returned 1 anyway.");
-        return 1;
-    }
-
     # this is either part of core or set up appropriately by MRO::Compat
     *check_package_cache_flag = \&mro::get_pkg_gen;
 }
 
-our $VERSION   = '0.92';
+our $VERSION   = '0.93';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
@@ -137,8 +132,12 @@ sub _try_load_one_class {
 }
 
 sub load_class {
-    my $class = load_first_existing_class($_[0]);
-    return get_metaclass_by_name($class) || $class;
+    load_first_existing_class($_[0]);
+
+    # This is done to avoid breaking code which checked the return value. Said
+    # code is dumb. The return value was _always_ true, since it dies on
+    # failure!
+    return 1;
 }
 
 sub _is_valid_class_name {
@@ -153,18 +152,6 @@ sub _is_valid_class_name {
     return 0;
 }
 
-sub subname {
-    require Sub::Name;
-    Carp::carp("Class::MOP::subname is deprecated. Please use Sub::Name directly.");
-    goto \&Sub::Name::subname;
-}
-
-sub in_global_destruction {
-    require Devel::GlobalDestruction;
-    Carp::carp("Class::MOP::in_global_destruction is deprecated. Please use Devel::GlobalDestruction directly.");
-    goto \&Devel::GlobalDestruction::in_global_destruction;
-}
-
 ## ----------------------------------------------------------------------------
 ## Setting up our environment ...
 ## ----------------------------------------------------------------------------
@@ -220,12 +207,12 @@ Class::MOP::Package->meta->add_attribute(
 );
 
 Class::MOP::Package->meta->add_attribute(
-    Class::MOP::Attribute->new('methods' => (
+    Class::MOP::Attribute->new('_methods' => (
         reader   => {
             # NOTE:
             # we just alias the original method
             # rather than re-produce it here
-            'get_method_map' => \&Class::MOP::Package::get_method_map
+            '_full_method_map' => \&Class::MOP::Package::_full_method_map
         },
         default => sub { {} }
     ))
@@ -676,6 +663,7 @@ Class::MOP::Instance->meta->add_attribute(
     ),
 );
 
+require Class::MOP::Deprecated unless our $no_deprecated;
 
 # we need the meta instance of the meta instance to be created now, in order
 # for the constructor to be able to use it
@@ -927,8 +915,11 @@ Note that these are all called as B<functions, not methods>.
 This will load the specified C<$class_name>, if it is not already
 loaded (as reported by C<is_class_loaded>). This function can be used
 in place of tricks like C<eval "use $module"> or using C<require>
-unconditionally. This will return the metaclass of C<$class_name> if
-one exists, otherwise it will return C<$class_name>.
+unconditionally.
+
+If the module cannot be loaded, an exception is thrown.
+
+For historical reasons, this function returns explicitly returns a true value.
 
 =item B<Class::MOP::is_class_loaded($class_name)>
 
@@ -1081,7 +1072,7 @@ L<http://citeseer.ist.psu.edu/37617.html>
 
 =over 4
 
-=item L<http://svn.openfoundry.org/pugs/perl5/Perl6-MetaModel>
+=item L<http://svn.openfoundry.org/pugs/misc/Perl-MetaModel/>
 
 =item L<http://svn.openfoundry.org/pugs/perl5/Perl6-ObjectSpace>
 
