@@ -6,7 +6,7 @@ use warnings;
 use Carp qw( cluck );
 use Scalar::Util qw( blessed );
 
-our $VERSION = '0.97_01';
+our $VERSION = '0.93';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -26,7 +26,6 @@ my %DeprecatedAt = (
     'Class::MOP::Class::alias_method'                      => 0.93,
     'Class::MOP::Class::compute_all_applicable_methods'    => 0.93,
     'Class::MOP::Class::compute_all_applicable_attributes' => 0.93,
-    'Class::MOP::Class::get_attribute_map' => 0.95,
 
     'Class::MOP::Instance::bless_instance_structure' => 0.93,
 
@@ -206,13 +205,6 @@ sub compute_all_applicable_attributes {
     shift->get_all_attributes(@_);
 }
 
-sub get_attribute_map {
-    Class::MOP::Deprecated::warn(
-        "The get_attribute_map method has been deprecated.\n");
-
-    shift->_attribute_map(@_);
-}
-
 package
     Class::MOP::Instance;
 
@@ -400,7 +392,7 @@ Goro Fuji E<lt>gfuji@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+Copyright 2006-2009 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
