@@ -6,7 +6,7 @@ use warnings;
 
 use Scalar::Util 'weaken', 'blessed';
 
-our $VERSION   = '0.92';
+our $VERSION   = '0.93';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -77,15 +77,6 @@ sub create_instance {
     bless {}, $self->_class_name;
 }
 
-# for compatibility
-sub bless_instance_structure {
-    Carp::cluck('The bless_instance_structure method is deprecated.'
-        . " It will be removed in a future release.\n");
-
-    my ($self, $instance_structure) = @_;
-    bless $instance_structure, $self->_class_name;
-}
-
 sub clone_instance {
     my ($self, $instance) = @_;
     bless { %$instance }, $self->_class_name;
