@@ -7,7 +7,7 @@ use warnings;
 use Carp         'confess';
 use Scalar::Util 'blessed', 'weaken';
 
-our $VERSION   = '0.92';
+our $VERSION   = '0.93';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -74,12 +74,6 @@ sub accessor_type        { (shift)->{'accessor_type'} }
 
 ## factory
 
-sub initialize_body {
-    Carp::cluck('The initialize_body method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n");
-    shift->_initialize_body;
-}
-
 sub _initialize_body {
     my $self = shift;
 
@@ -95,12 +89,6 @@ sub _initialize_body {
 
 ## generators
 
-sub generate_accessor_method {
-    Carp::cluck('The generate_accessor_method method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n");
-    shift->_generate_accessor_method;
-}
-
 sub _generate_accessor_method {
     my $attr = (shift)->associated_attribute;
     return sub {
@@ -109,12 +97,6 @@ sub _generate_accessor_method {
     };
 }
 
-sub generate_reader_method {
-    Carp::cluck('The generate_reader_method method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n");
-    shift->_generate_reader_method;
-}
-
 sub _generate_reader_method {
     my $attr = (shift)->associated_attribute;
     return sub {
@@ -123,11 +105,6 @@ sub _generate_reader_method {
     };
 }
 
-sub generate_writer_method {
-    Carp::cluck('The generate_writer_method method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n");
-    shift->_generate_writer_method;
-}
 
 sub _generate_writer_method {
     my $attr = (shift)->associated_attribute;
@@ -136,12 +113,6 @@ sub _generate_writer_method {
     };
 }
 
-sub generate_predicate_method {
-    Carp::cluck('The generate_predicate_method method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n");
-    shift->_generate_predicate_method;
-}
-
 sub _generate_predicate_method {
     my $attr = (shift)->associated_attribute;
     return sub {
@@ -149,12 +120,6 @@ sub _generate_predicate_method {
     };
 }
 
-sub generate_clearer_method {
-    Carp::cluck('The generate_clearer_method method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n");
-    shift->_generate_clearer_method;
-}
-
 sub _generate_clearer_method {
     my $attr = (shift)->associated_attribute;
     return sub {
@@ -164,12 +129,6 @@ sub _generate_clearer_method {
 
 ## Inline methods
 
-sub generate_accessor_method_inline {
-    Carp::cluck('The generate_accessor_method_inline method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n");
-    shift->_generate_accessor_method_inline;
-}
-
 sub _generate_accessor_method_inline {
     my $self          = shift;
     my $attr          = $self->associated_attribute;
@@ -189,12 +148,6 @@ sub _generate_accessor_method_inline {
     return $code;
 }
 
-sub generate_reader_method_inline {
-    Carp::cluck('The generate_reader_method_inline method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n");
-    shift->_generate_reader_method_inline;
-}
-
 sub _generate_reader_method_inline {
     my $self          = shift;
     my $attr          = $self->associated_attribute;
@@ -213,12 +166,6 @@ sub _generate_reader_method_inline {
     return $code;
 }
 
-sub generate_writer_method_inline {
-    Carp::cluck('The generate_writer_method_inline method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n");
-    shift->_generate_writer_method_inline;
-}
-
 sub _generate_writer_method_inline {
     my $self          = shift;
     my $attr          = $self->associated_attribute;
@@ -236,12 +183,6 @@ sub _generate_writer_method_inline {
     return $code;
 }
 
-sub generate_predicate_method_inline {
-    Carp::cluck('The generate_predicate_method_inline method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n");
-    shift->_generate_predicate_method_inline;
-}
-
 sub _generate_predicate_method_inline {
     my $self          = shift;
     my $attr          = $self->associated_attribute;
@@ -259,12 +200,6 @@ sub _generate_predicate_method_inline {
     return $code;
 }
 
-sub generate_clearer_method_inline {
-    Carp::cluck('The generate_clearer_method_inline method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n");
-    shift->_generate_clearer_method_inline;
-}
-
 sub _generate_clearer_method_inline {
     my $self          = shift;
     my $attr          = $self->associated_attribute;
